# Deidentify (deid)

Deidentify medical images in Python.

[![Build Status](https://travis-ci.org/pydicom/deid.svg?branch=master)](https://travis-ci.org/pydicom/deid)

Please see our [Documentation](https://pydicom.github.io/deid/)

These are basic Python based tools for working with medical images and text, specifically for de-identification.


## Installation
For the stable release, install via pip:

```
pip install deid
```

For the development version, install from Github:

```
pip install git+git://github.com/pydicom/deid
```

## Issues
If you have an issue, or want to request a feature, please do so on our [issues board](https://www.github.com/pydicom/deid/issues)
